LoopFilterParams

Struct LoopFilterParams 

pub struct LoopFilterParams {
    pub level: [u8; 4],
    pub sharpness: u8,
    pub delta_enabled: bool,
    pub delta_update: bool,
    pub ref_deltas: [i8; 8],
    pub mode_deltas: [i8; 2],
}
Loop filter parameters as parsed from the frame header.

Fields

level: [u8; 4]

Loop filter level for Y vertical edges.

sharpness: u8

Sharpness level (0-7).

delta_enabled: bool

Delta coding enabled.

delta_update: bool

Update delta values.

ref_deltas: [i8; 8]

Reference frame deltas.

mode_deltas: [i8; 2]

Mode deltas (for ZERO_MV and MV modes).

Implementations

Source

impl LoopFilterParams

pub fn new() -> Self

Create a new loop filter params with default values.

pub fn parse( reader: &mut BitReader<'_>, seq: &SequenceHeader, frame_is_intra: bool, ) -> CodecResult<Self>

Parse loop filter parameters from the bitstream.

Errors

Returns error if the bitstream is malformed.

pub const fn level_y_v(&self) -> u8

Get the Y vertical filter level.

pub const fn level_y_h(&self) -> u8

Get the Y horizontal filter level.

pub const fn level_u(&self) -> u8

Get the U filter level.

pub const fn level_v(&self) -> u8

Get the V filter level.

pub fn is_enabled(&self) -> bool

Check if loop filter is enabled for any plane.

pub fn get_level(&self, plane: usize, direction: usize) -> u8

Get the filter level for a specific plane and direction.

Arguments
  • plane - Plane index (0=Y, 1=U, 2=V)
  • direction - 0 for vertical, 1 for horizontal
pub fn compute_level( &self, base_level: u8, ref_frame: usize, mode: usize, segment_delta: i16, ) -> u8

Compute the filter level for a block.

This applies delta adjustments based on reference frame and mode.

Arguments
  • base_level - Base filter level from frame header
  • ref_frame - Reference frame index (0 for intra)
  • mode - Mode index (0 for ZEROMV, 1 for other MV modes)
  • segment_delta - Delta from segmentation
pub fn get_limit(&self, level: u8) -> u8

Get the limit value for the filter based on sharpness.

The limit determines the maximum difference for the filter to be applied.

pub fn get_threshold(&self, level: u8) -> u8

Get the threshold value for the filter.

pub const fn get_hev_threshold(&self, level: u8) -> u8

Get the high edge variance threshold.

pub const fn has_delta_updates(&self) -> bool

Check if delta updates are present.

pub fn reset_deltas(&mut self)

Reset deltas to default values.

pub fn set_level_all(&mut self, level: u8)

Set filter level for all planes.

pub fn to_bytes(&self, seq: &SequenceHeader, frame_is_intra: bool) -> Vec<u8>

Serialize loop filter parameters to bitstream.