pub struct OperatingPoint {
pub idc: u16,
pub temporal_id: u8,
pub spatial_id: u8,
pub level: u8,
pub tier: u8,
pub cumulative_bitrate_fraction: f32,
pub cumulative_framerate_fraction: f32,
}Expand description
An AV1 operating point defined by temporal+spatial layer combination.
Fields
idc: u16Operating point IDC bitmask (bits 0-7: temporal, bits 8-11: spatial).
temporal_id: u8Maximum temporal ID included.
spatial_id: u8Maximum spatial ID included.
level: u8AV1 level index for this operating point.
tier: u8Tier (0 = Main, 1 = High).
cumulative_bitrate_fraction: f32Cumulative bitrate fraction up to this temporal layer.
cumulative_framerate_fraction: f32Cumulative framerate fraction at this temporal layer.
Implementations
Sourceimpl OperatingPoint
impl OperatingPoint
Sourcepub fn compute_idc(max_temporal_id: u8, max_spatial_id: u8) -> u16
pub fn compute_idc(max_temporal_id: u8, max_spatial_id: u8) -> u16
Get the operating point IDC for a given temporal and spatial layer set.
Sourcepub fn includes_temporal(&self, temporal_id: u8) -> bool
pub fn includes_temporal(&self, temporal_id: u8) -> bool
Check if this operating point includes a given temporal layer.
Sourcepub fn includes_spatial(&self, spatial_id: u8) -> bool
pub fn includes_spatial(&self, spatial_id: u8) -> bool
Check if this operating point includes a given spatial layer.