pub struct TileGroup {
pub tile_start: u32,
pub tile_end: u32,
pub tiles: Vec<TileData>,
pub num_tiles: u32,
}Expand description
Tile group header and data.
Fields
tile_start: u32Starting tile index (inclusive).
tile_end: u32Ending tile index (inclusive).
tiles: Vec<TileData>Tile data entries.
num_tiles: u32Number of tiles signaled.
Implementations
Sourceimpl TileGroup
impl TileGroup
Sourcepub fn tile_count(&self) -> u32
pub fn tile_count(&self) -> u32
Get number of tiles in this group.
Sourcepub fn get_tile(&self, idx: usize) -> Option<&TileData>
pub fn get_tile(&self, idx: usize) -> Option<&TileData>
Get a tile by its index within the group.
Sourcepub const fn contains_tile(&self, tile_idx: u32) -> bool
pub const fn contains_tile(&self, tile_idx: u32) -> bool
Check if this group contains a specific tile index.
Sourcepub const fn is_single_tile(&self) -> bool
pub const fn is_single_tile(&self) -> bool
Check if this is a single-tile group.