TileInfo

Struct TileInfo 

pub struct TileInfo {
Show 16 fields pub tile_cols: u32, pub tile_rows: u32, pub tile_col_starts: Vec<u32>, pub tile_row_starts: Vec<u32>, pub context_update_tile_id: u32, pub tile_size_bytes: u8, pub uniform_tile_spacing: bool, pub tile_cols_log2: u8, pub tile_rows_log2: u8, pub min_tile_cols_log2: u8, pub max_tile_cols_log2: u8, pub min_tile_rows_log2: u8, pub max_tile_rows_log2: u8, pub sb_cols: u32, pub sb_rows: u32, pub sb_size: u32,
}
Tile information from frame header.

Fields

tile_cols: u32

Number of tile columns.

tile_rows: u32

Number of tile rows.

tile_col_starts: Vec<u32>

Tile column start positions (in superblocks).

tile_row_starts: Vec<u32>

Tile row start positions (in superblocks).

context_update_tile_id: u32

Context update tile ID.

tile_size_bytes: u8

Number of bytes to read for tile size.

uniform_tile_spacing: bool

Uniform tile spacing flag.

tile_cols_log2: u8

Tile columns log2.

tile_rows_log2: u8

Tile rows log2.

min_tile_cols_log2: u8

Minimum tile columns log2.

max_tile_cols_log2: u8

Maximum tile columns log2.

min_tile_rows_log2: u8

Minimum tile rows log2.

max_tile_rows_log2: u8

Maximum tile rows log2.

sb_cols: u32

Superblock columns.

sb_rows: u32

Superblock rows.

sb_size: u32

Superblock size (64 or 128).

Implementations

Source

impl TileInfo

pub fn new() -> Self

Create a new tile info with default values.

pub fn parse( reader: &mut BitReader<'_>, _seq: &SequenceHeader, frame_size: &FrameSize, ) -> CodecResult<Self>

Parse tile info from the bitstream.

Errors

Returns error if the bitstream is malformed.

pub const fn tile_count(&self) -> u32

Get total number of tiles.

pub fn tile_size_sb(&self, tile_col: u32, tile_row: u32) -> (u32, u32)

Get tile dimensions in superblocks for a specific tile.

pub fn tile_size_pixels(&self, tile_col: u32, tile_row: u32) -> (u32, u32)

Get tile dimensions in pixels for a specific tile.

pub const fn tile_index(&self, tile_col: u32, tile_row: u32) -> u32

Get the tile index for a given (col, row) position.

pub const fn tile_position(&self, tile_idx: u32) -> (u32, u32)

Get the (col, row) position for a tile index.

pub fn tile_col_start_sb(&self, tile_col: u32) -> u32

Get the starting superblock column for a tile column.

pub fn tile_row_start_sb(&self, tile_row: u32) -> u32

Get the starting superblock row for a tile row.

pub fn tile_start_pixels(&self, tile_col: u32, tile_row: u32) -> (u32, u32)

Get the pixel position for the start of a tile.

pub const fn is_single_tile(&self) -> bool

Check if this is a single-tile frame.

pub const fn is_left_edge(&self, tile_col: u32) -> bool

Check if a tile is at the left edge.

pub fn is_right_edge(&self, tile_col: u32) -> bool

Check if a tile is at the right edge.

pub const fn is_top_edge(&self, tile_row: u32) -> bool

Check if a tile is at the top edge.

pub fn is_bottom_edge(&self, tile_row: u32) -> bool

Check if a tile is at the bottom edge.