pub struct TileRegion {
pub col: u32,
pub row: u32,
pub x: u32,
pub y: u32,
pub width: u32,
pub height: u32,
pub index: u32,
}Expand description
Describes a rectangular tile region within a frame.
Fields
col: u32Tile column index.
row: u32Tile row index.
x: u32X offset in pixels.
y: u32Y offset in pixels.
width: u32Width in pixels.
height: u32Height in pixels.
index: u32Tile index in raster order.
Implementations
Sourceimpl TileRegion
impl TileRegion
Sourcepub const fn new(
col: u32,
row: u32,
x: u32,
y: u32,
width: u32,
height: u32,
tile_cols: u32,
) -> Self
pub const fn new( col: u32, row: u32, x: u32, y: u32, width: u32, height: u32, tile_cols: u32, ) -> Self
Create a new tile region.
Sourcepub const fn is_left_edge(&self) -> bool
pub const fn is_left_edge(&self) -> bool
Check if this tile is at the left edge.
Sourcepub const fn is_top_edge(&self) -> bool
pub const fn is_top_edge(&self) -> bool
Check if this tile is at the top edge.