pub struct AvifDecoder;Expand description
Decodes AVIF container bytes to AvifImage.
Implementations
Sourceimpl AvifDecoder
impl AvifDecoder
Sourcepub fn decode(data: &[u8]) -> Result<AvifImage, CodecError>
pub fn decode(data: &[u8]) -> Result<AvifImage, CodecError>
Decode a complete AVIF byte stream.
This parses the ISOBMFF container, extracts spatial/colour metadata
from the iprp boxes, and returns the raw AV1 bitstream in the
y_plane field (full decode of AV1 frames is out of scope for this
implementation; the bitstream is available for further processing).
Sourcepub fn probe(data: &[u8]) -> Result<AvifProbeResult, CodecError>
pub fn probe(data: &[u8]) -> Result<AvifProbeResult, CodecError>
Probe a AVIF byte stream for basic metadata without full decoding.