pub struct CeltFrameConfig {
pub frame_size: usize,
pub channels: u8,
pub start_band: u8,
pub end_band: u8,
}Expand description
Configuration for a CELT frame decoder.
Fields
frame_size: usizeFrame size in samples (120, 240, 480, 960, or 1920).
channels: u8Number of audio channels (1 or 2).
start_band: u8First band index (for hybrid Opus mode).
end_band: u8One-past-last band index.
Implementations
Sourceimpl CeltFrameConfig
impl CeltFrameConfig
Sourcepub fn with_frame_size(self, frame_size: usize) -> Self
pub fn with_frame_size(self, frame_size: usize) -> Self
Sets the frame size and returns self for chaining.
Sourcepub fn with_channels(self, channels: u8) -> Self
pub fn with_channels(self, channels: u8) -> Self
Sets the channel count and returns self for chaining.
Sourcepub fn with_start_band(self, start_band: u8) -> Self
pub fn with_start_band(self, start_band: u8) -> Self
Sets the start band and returns self for chaining.
Sourcepub fn with_end_band(self, end_band: u8) -> Self
pub fn with_end_band(self, end_band: u8) -> Self
Sets the end band and returns self for chaining.