pub fn probe_codec(data: &[u8], codec: CodecId) -> ProbeResultExpand description
Probe data against a specific codec and return the result.
pub fn probe_codec(data: &[u8], codec: CodecId) -> ProbeResultProbe data against a specific codec and return the result.