pub struct HwDecodeCapability {
pub tier: HwDecoderTier,
pub av1_profiles: Vec<Av1Profile>,
pub vp9_profiles: Vec<Vp9Profile>,
pub max_bit_depth: u8,
pub max_resolution: (u32, u32),
pub hdr_supported: bool,
}Expand description
Hardware decode capability for a specific decoder tier.
Fields
tier: HwDecoderTierTier of the hardware.
av1_profiles: Vec<Av1Profile>Supported AV1 profiles.
vp9_profiles: Vec<Vp9Profile>Supported VP9 profiles.
max_bit_depth: u8Maximum supported bit depth.
max_resolution: (u32, u32)Maximum resolution (width, height).
hdr_supported: boolWhether HDR / HLG is supported.
Implementations
Sourceimpl HwDecodeCapability
impl HwDecodeCapability
Sourcepub fn can_decode_av1(&self, profile: &Av1Profile, bit_depth: u8) -> bool
pub fn can_decode_av1(&self, profile: &Av1Profile, bit_depth: u8) -> bool
Check if this hardware can decode the given AV1 profile and bit depth.
Sourcepub fn can_decode_vp9(&self, profile: &Vp9Profile, bit_depth: u8) -> bool
pub fn can_decode_vp9(&self, profile: &Vp9Profile, bit_depth: u8) -> bool
Check if this hardware can decode the given VP9 profile and bit depth.
Sourcepub fn can_handle_resolution(&self, width: u32, height: u32) -> bool
pub fn can_handle_resolution(&self, width: u32, height: u32) -> bool
Check if resolution is within hardware limits.