LevelRange

Struct LevelRange 

pub struct LevelRange {
    pub luma_min: u16,
    pub luma_max: u16,
    pub chroma_min: u16,
    pub chroma_max: u16,
}
Level range for a given color range and bit depth.

Fields

luma_min: u16

Minimum luma value.

luma_max: u16

Maximum luma value.

chroma_min: u16

Minimum chroma value.

chroma_max: u16

Maximum chroma value.

Implementations

Source

impl LevelRange

pub fn new(range: ColorRange, depth: BitDepth) -> Self

Create a level range for the given color range and bit depth.

pub fn luma_span(&self) -> u16

Luma span (max - min).

pub fn chroma_span(&self) -> u16

Chroma span (max - min).