pub struct TableArithmeticDecoder<'a> { /* private fields */ }Expand description
Table-based arithmetic decoder counterpart.
Reads bytes from a pre-encoded stream and reconstructs symbols using the same probability table used during encoding.
Implementations
Sourceimpl<'a> TableArithmeticDecoder<'a>
impl<'a> TableArithmeticDecoder<'a>
Sourcepub fn new(data: &'a [u8]) -> Self
pub fn new(data: &'a [u8]) -> Self
Create a decoder over data.
Reads the initial 4-byte code word.
Sourcepub fn decode_symbol(&mut self, entry: &ProbTableEntry) -> bool
pub fn decode_symbol(&mut self, entry: &ProbTableEntry) -> bool
Decode one symbol.
Returns true for the high partition, false for the low partition.