Module features

Module features 

Codec capability and feature detection.

CodecFeatures provides a runtime query interface for the capabilities of a named codec (e.g. "av1", "vp9", "opus"). The information is based on a static capability table and can be used by higher-level pipeline code to select the correct encoder/decoder configuration.

Structs

CodecFeatures
Capability flags for a specific codec.

Type Aliases

CodecId
A codec name as a borrowed or owned string.