Module range_coder

Module range_coder 

FFV1 range coder implementation.

FFV1 v3 uses an adaptive binary arithmetic coder (range coder) for entropy coding. Each binary decision uses an adaptive probability state that is updated after each coded bit via a state transition table.

The range coder operates on a 16-bit range and reads/writes bytes one at a time. The state transition table is defined in RFC 9043 Section 4.1.

Structs

SimpleRangeDecoder
Range coder decoder for FFV1.
SimpleRangeEncoder
Range coder encoder for FFV1.