pub struct SimpleRangeDecoder { /* private fields */ }Expand description
Range coder decoder for FFV1.
Reads entropy-coded binary decisions from a byte buffer using adaptive probability states.
Implementations
Sourceimpl SimpleRangeDecoder
impl SimpleRangeDecoder
Sourcepub fn new(data: &[u8]) -> CodecResult<Self>
pub fn new(data: &[u8]) -> CodecResult<Self>
Create a new range decoder from the given data.
Sourcepub fn get_bit(&mut self, state: &mut u8) -> CodecResult<bool>
pub fn get_bit(&mut self, state: &mut u8) -> CodecResult<bool>
Decode a single binary decision using the given adaptive state.
Sourcepub fn get_symbol(&mut self, states: &mut [u8]) -> CodecResult<i32>
pub fn get_symbol(&mut self, states: &mut [u8]) -> CodecResult<i32>
Decode a signed symbol using the given context states.
Sourcepub fn bytes_consumed(&self) -> usize
pub fn bytes_consumed(&self) -> usize
Number of bytes consumed so far.