GifDecoder

Struct GifDecoder 

pub struct GifDecoder { /* private fields */ }
GIF decoder for reading GIF89a files.

Supports:

  • Single images and animations
  • Transparency
  • Interlaced images
  • Global and local color tables

Implementations

Source

impl GifDecoder

pub fn new(data: &[u8]) -> CodecResult<Self>

Create a new GIF decoder from data.

Arguments
  • data - GIF file data
Errors

Returns error if data is not a valid GIF file.

pub fn width(&self) -> u32

Get canvas width.

pub fn height(&self) -> u32

Get canvas height.

pub fn frame_count(&self) -> usize

Get number of frames.

pub fn loop_count(&self) -> u16

Get loop count (0 = infinite).

pub fn screen_descriptor(&self) -> &LogicalScreenDescriptor

Get the logical screen descriptor.

pub fn global_color_table(&self) -> &[u8]

Get the global color table.

pub fn frame_info(&self, index: usize) -> CodecResult<&GifFrame>

Get frame information.

Arguments
  • index - Frame index
Errors

Returns error if index is out of range.

pub fn decode_frame(&self, index: usize) -> CodecResult<VideoFrame>

Decode a specific frame.

Arguments
  • index - Frame index to decode
Errors

Returns error if decoding fails or index is out of range.

pub fn decode_all_frames(&self) -> CodecResult<Vec<VideoFrame>>

Decode all frames.

Errors

Returns error if decoding fails.

pub fn frame_delay_ms(&self, index: usize) -> CodecResult<u32>

Get frame delay time in milliseconds.

Arguments
  • index - Frame index
Errors

Returns error if index is out of range.

pub fn frame_has_transparency(&self, index: usize) -> CodecResult<bool>

Check if frame has transparency.

Arguments
  • index - Frame index
Errors

Returns error if index is out of range.

pub fn frame_disposal_method(&self, index: usize) -> CodecResult<DisposalMethod>

Get frame disposal method.

Arguments
  • index - Frame index
Errors

Returns error if index is out of range.

pub fn is_animated(&self) -> bool

Check if this is an animated GIF.

pub fn total_duration_ms(&self) -> u32

Get total animation duration in milliseconds.