AnimatedJxlEncoder

Struct AnimatedJxlEncoder 

pub struct AnimatedJxlEncoder { /* private fields */ }
Animated JPEG-XL encoder.

Builds a multi-frame JPEG-XL codestream by accumulating frames via add_frame and then producing the final codestream with finish.

Codestream Layout

[signature (2 bytes)] [size_header] [image_metadata with animation]
[frame_header_0] [align] [frame_data_0]
[frame_header_1] [align] [frame_data_1]
...
[frame_header_N] [align] [frame_data_N]   (is_last = true)

Examples

use oximedia_codec::jpegxl::{AnimatedJxlEncoder, JxlAnimation};

let anim = JxlAnimation::millisecond();
let mut encoder = AnimatedJxlEncoder::new(anim, 8, 8, 3, 8)?;
encoder.add_frame(&frame0_data, 100)?;  // 100ms
encoder.add_frame(&frame1_data, 200)?;  // 200ms
let codestream = encoder.finish()?;

Implementations

Source

impl AnimatedJxlEncoder

pub fn new( animation: JxlAnimation, width: u32, height: u32, channels: u8, bit_depth: u8, ) -> CodecResult<Self>

Create a new animated encoder.

Arguments
  • animation - Animation timing configuration
  • width - Frame width in pixels (shared by all frames)
  • height - Frame height in pixels (shared by all frames)
  • channels - Number of channels (1=gray, 3=RGB, 4=RGBA)
  • bit_depth - Bits per sample (8 or 16)
Errors

Returns error if dimensions, channels, or bit depth are invalid.

pub fn with_effort(self, effort: u8) -> Self

Set encoding effort (1-9).

pub fn add_frame(&mut self, data: &[u8], duration_ticks: u32) -> CodecResult<()>

Add a frame to the animation.

Arguments
  • data - Interleaved pixel data for this frame (same layout as JxlEncoder::encode)
  • duration_ticks - Duration of this frame in ticks (relative to animation tick rate)
Errors

Returns error if the data size is wrong or encoding fails.

pub fn frame_count(&self) -> usize

Number of frames added so far.

pub fn finish_isobmff(self) -> CodecResult<Vec<u8>>

Finalize and wrap the animated codestream in an ISOBMFF container.

Produces a file beginning with a ftyp box (major brand jxl ), followed by a jxll box and a single jxlp box containing the bare codestream with the is_last flag set.

Errors

Returns error if no frames have been added or encoding fails.

pub fn finish(self) -> CodecResult<Vec<u8>>

Finalize the animated codestream.

Produces the complete multi-frame JPEG-XL bare codestream. The last frame is automatically marked with is_last = true.

Errors

Returns error if no frames have been added.