pub struct BitWriter { /* private fields */ }Expand description
Bit-level writer for constructing JPEG-XL bitstreams.
Writes bits in LSB-first order, accumulating a byte buffer.
Implementations
Sourceimpl BitWriter
impl BitWriter
Sourcepub fn with_capacity(bytes: usize) -> Self
pub fn with_capacity(bytes: usize) -> Self
Create a new bit writer with pre-allocated capacity (in bytes).
Sourcepub fn write_bits(&mut self, value: u32, n: u8)
pub fn write_bits(&mut self, value: u32, n: u8)
Write up to 32 bits (LSB first).
Sourcepub fn write_bool(&mut self, v: bool)
pub fn write_bool(&mut self, v: bool)
Write a single boolean bit.
Sourcepub fn align_to_byte(&mut self)
pub fn align_to_byte(&mut self)
Align to the next byte boundary by writing zero bits.
Sourcepub fn finish(self) -> Vec<u8> ⓘ
pub fn finish(self) -> Vec<u8> ⓘ
Consume the writer and return the accumulated byte buffer.
Any partial byte is flushed with zero-padding.
Sourcepub fn bytes_written(&self) -> usize
pub fn bytes_written(&self) -> usize
Current number of bytes written (excluding partial byte).
Sourcepub fn bits_written(&self) -> usize
pub fn bits_written(&self) -> usize
Current total bits written.