pub struct LevelConstraints {
pub max_width: u32,
pub max_height: u32,
pub max_sample_rate: u64,
pub max_bitrate_main: u64,
pub max_bitrate_high: u64,
pub max_ref_frames: u8,
pub max_tile_cols: u8,
pub max_tile_rows: u8,
}Expand description
Constraints imposed by a profile/level combination.
Fields
max_width: u32Maximum picture width in pixels.
max_height: u32Maximum picture height in pixels.
max_sample_rate: u64Maximum luma sample rate (samples per second).
max_bitrate_main: u64Maximum bitrate in bits per second for main tier.
max_bitrate_high: u64Maximum bitrate in bits per second for high tier.
max_ref_frames: u8Maximum number of reference frames.
max_tile_cols: u8Maximum number of tile columns.
max_tile_rows: u8Maximum number of tile rows.
Implementations
Sourceimpl LevelConstraints
impl LevelConstraints
Sourcepub fn max_bitrate(&self, tier: Tier) -> u64
pub fn max_bitrate(&self, tier: Tier) -> u64
Maximum bitrate for the given tier.
Sourcepub fn max_pixels(&self) -> u64
pub fn max_pixels(&self) -> u64
Maximum total pixel count (width * height).