pub struct BufferModel { /* private fields */ }Expand description
Buffer model for HRD (Hypothetical Reference Decoder) compliance.
Implements the CPB (Coded Picture Buffer) model as defined in video coding standards for streaming compliance.
Implementations
Sourceimpl BufferModel
impl BufferModel
Sourcepub fn new(
cpb_size: u64,
bitrate: u64,
framerate: f64,
initial_delay: f64,
) -> Self
pub fn new( cpb_size: u64, bitrate: u64, framerate: f64, initial_delay: f64, ) -> Self
Create a new buffer model.
Sourcepub fn fill_for_frame(&mut self)
pub fn fill_for_frame(&mut self)
Fill buffer at constant bitrate for one frame duration.
Sourcepub fn remove_frame_bits(&mut self, bits: u64)
pub fn remove_frame_bits(&mut self, bits: u64)
Remove bits for an encoded frame.
Sourcepub fn encode_frame(&mut self, bits: u64)
pub fn encode_frame(&mut self, bits: u64)
Simulate encoding a frame with the given bits.
Fills the buffer, then removes the frame bits.
Sourcepub fn max_frame_bits(&self) -> u64
pub fn max_frame_bits(&self) -> u64
Get maximum bits allowed for next frame (before overflow).
Sourcepub fn min_frame_bits(&self) -> u64
pub fn min_frame_bits(&self) -> u64
Get minimum bits required for next frame (before underflow).
Sourcepub fn is_healthy(&self) -> bool
pub fn is_healthy(&self) -> bool
Check if the buffer is in a healthy state.
Sourcepub fn overflow_count(&self) -> u64
pub fn overflow_count(&self) -> u64
Get overflow count.
Sourcepub fn underflow_count(&self) -> u64
pub fn underflow_count(&self) -> u64
Get underflow count.