pub struct Scene {
pub start_frame: u64,
pub end_frame: u64,
pub content_type: SceneContentType,
pub avg_spatial: f32,
pub avg_temporal: f32,
}Expand description
A contiguous run of frames that share the same scene.
Fields
start_frame: u64Index of the first frame in this scene.
end_frame: u64Index of the last frame in this scene (inclusive).
content_type: SceneContentTypeDominant content classification for this scene.
avg_spatial: f32Average spatial complexity across the scene.
avg_temporal: f32Average temporal complexity across the scene.
Implementations
Sourceimpl Scene
impl Scene
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Number of frames in the scene.
Sourcepub fn bit_multiplier(&self) -> f32
pub fn bit_multiplier(&self) -> f32
Bit-allocation multiplier for this scene.