pub struct RefFrame {
pub poc: i32,
pub frame_num: u32,
pub ref_type: RefFrameType,
pub in_use: bool,
pub buffer_index: usize,
}Expand description
A reference frame entry in the decoded picture buffer.
Fields
poc: i32Picture order count (POC).
frame_num: u32frame_num for short-term or long-term frame index for long-term.
ref_type: RefFrameTypeReference type.
in_use: booltrue when this entry is actually in use (not an empty slot).
buffer_index: usizeOpaque frame data buffer index (into a larger buffer pool).
Implementations
Sourceimpl RefFrame
impl RefFrame
Sourcepub fn short_term(poc: i32, frame_num: u32, buffer_index: usize) -> Self
pub fn short_term(poc: i32, frame_num: u32, buffer_index: usize) -> Self
Creates a new short-term reference frame.
Sourcepub fn long_term(
poc: i32,
long_term_frame_idx: u32,
buffer_index: usize,
) -> Self
pub fn long_term( poc: i32, long_term_frame_idx: u32, buffer_index: usize, ) -> Self
Creates a new long-term reference frame.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns true when this slot is occupied by a valid reference frame.
Sourcepub fn mark_unused(&mut self)
pub fn mark_unused(&mut self)
Marks this frame as unused (removes it from the DPB logically).