FilterOps

Struct FilterOps 

pub struct FilterOps<S: SimdOps> { /* private fields */ }
Filter operations using SIMD.

Implementations

Source

impl<S: SimdOps> FilterOps<S>

pub const fn new(simd: S) -> Self

Create a new filter operations instance.

pub const fn simd(&self) -> &S

Get the underlying SIMD implementation.

pub fn filter_h_2tap(&self, src: &[u8], dst: &mut [u8], width: usize)

Apply a horizontal 2-tap filter (bilinear).

Used for simple 2x scaling or half-pixel interpolation.

pub fn filter_h_4tap( &self, src: &[u8], dst: &mut [u8], coeffs: &[i16; 4], width: usize, )

Apply a horizontal 4-tap filter.

Common filter coefficients for sub-pixel interpolation.

pub fn filter_h_6tap( &self, src: &[u8], dst: &mut [u8], coeffs: &[i16; 6], width: usize, )

Apply a horizontal 6-tap filter.

pub fn filter_h_8tap( &self, src: &[u8], dst: &mut [u8], coeffs: &[i16; 8], width: usize, )

Apply a horizontal 8-tap filter.

Used in AV1 for high-quality scaling.

pub fn filter_v_8tap( &self, rows: &[&[u8]; 8], col: usize, coeffs: &[i16; 8], ) -> u8

Apply a vertical filter to a column of pixels.

Takes pointers to multiple rows and produces one output pixel.

pub fn filter_v_row_8tap( &self, rows: &[&[u8]; 8], dst: &mut [u8], coeffs: &[i16; 8], width: usize, )

Apply vertical filter to a row of pixels.

Source

impl<S: SimdOps + SimdOpsExt> FilterOps<S>

pub fn filter_h_8tap_simd( &self, src: &[u8], dst: &mut [u8], coeffs: &[i16; 8], width: usize, )

SIMD-accelerated horizontal 8-tap filter.