I32x8

Struct I32x8 

pub struct I32x8(pub [i32; 8]);
8-lane vector of 32-bit signed integers (256-bit).

Common uses:

  • Wide accumulation
  • 8-point parallel operations

Tuple Fields

0: [i32; 8]

Implementations

Source

impl I32x8

pub const fn zero() -> Self

Create a new vector with all lanes set to zero.

pub const fn splat(value: i32) -> Self

Create a new vector with all lanes set to the same value.

pub const fn from_array(arr: [i32; 8]) -> Self

Create a vector from an array.

pub const fn to_array(self) -> [i32; 8]

Convert to an array.

pub fn horizontal_sum(self) -> i32

Horizontal sum of all elements.