U8x16

Struct U8x16 

pub struct U8x16(pub [u8; 16]);
16-lane vector of 8-bit unsigned integers (128-bit).

Common uses:

  • Raw pixel data
  • SAD calculations
  • Luma/chroma samples

Tuple Fields

0: [u8; 16]

Implementations

Source

impl U8x16

pub const fn zero() -> Self

Create a new vector with all lanes set to zero.

pub const fn splat(value: u8) -> Self

Create a new vector with all lanes set to the same value.

pub const fn from_array(arr: [u8; 16]) -> Self

Create a vector from an array.

pub const fn to_array(self) -> [u8; 16]

Convert to an array.

pub fn get(&self, index: usize) -> u8

Get element at index.

pub fn set(&mut self, index: usize, value: u8)

Set element at index.

pub fn widen_low_i16(self) -> I16x8

Widen low 8 bytes to I16x8.

pub fn widen_high_i16(self) -> I16x8

Widen high 8 bytes to I16x8.

pub const fn as_ptr(&self) -> *const u8

Get a pointer to the underlying array.

pub fn as_mut_ptr(&mut self) -> *mut u8

Get a mutable pointer to the underlying array.

pub fn iter(&self) -> Iter<'_, u8>

Get an iterator over the elements.

pub fn copy_from_slice(&mut self, src: &[u8])

Copy elements from a slice.