U8x32

Struct U8x32 

pub struct U8x32(pub [u8; 32]);
32-lane vector of 8-bit unsigned integers (256-bit).

Common uses:

  • Wide pixel operations
  • AVX-width processing

Tuple Fields

0: [u8; 32]

Implementations

Source

impl U8x32

pub const fn zero() -> Self

Create a new vector with all lanes set to zero.

pub const fn splat(value: u8) -> Self

Create a new vector with all lanes set to the same value.

pub const fn from_array(arr: [u8; 32]) -> Self

Create a vector from an array.

pub const fn to_array(self) -> [u8; 32]

Convert to an array.

pub fn split(self) -> (U8x16, U8x16)

Split into two U8x16 vectors.

pub const fn as_ptr(&self) -> *const u8

Get a pointer to the underlying array.