pub enum SliceType {
P,
B,
I,
Sp,
Si,
}Expand description
H.264 slice types as defined in Table 7-6.
The spec defines values 0–9; values 5–9 are equivalent to 0–4 but signal that all slices in the picture are the same type.
Variants
P
Predictive slice (inter-predicted from reference frames).
B
Bi-predictive slice (two reference frames).
I
Intra-only slice.
Sp
Switching P slice.
Si
Switching I slice.
Implementations
Sourceimpl SliceType
impl SliceType
Sourcepub fn is_bipredictive(self) -> bool
pub fn is_bipredictive(self) -> bool
Returns true when this is a bi-predictive slice.
Sourcepub fn is_switching(self) -> bool
pub fn is_switching(self) -> bool
Returns true when this is a switching slice (SP or SI).