decode_tile_stream

Function decode_tile_stream 

pub fn decode_tile_stream(stream: &[u8]) -> CodecResult<Vec<Vec<u8>>>
Decode a tile stream produced by assemble_tiles.

Returns a Vec of raw per-tile byte payloads in the order they were stored (which is raster order when the encoder was used correctly).

Errors

Returns CodecError::InvalidBitstream if the stream is truncated or the encoded tile count is inconsistent with the data length.