pub struct HeaderedTileEncodeOp;Expand description
A simple op that encodes a tile with a small header describing its position and appends placeholder compressed data.
Header layout:
[4 bytes LE: x offset]
[4 bytes LE: y offset]
[4 bytes LE: width]
[4 bytes LE: height]
[1 byte: tile col index]
[1 byte: tile row index]Followed by raw luma bytes.