TileConfig

Struct TileConfig 

pub struct TileConfig {
    pub tile_cols: u32,
    pub tile_rows: u32,
    pub threads: usize,
}
Configuration for the tile grid used during parallel encoding.

Tile counts must be positive integers ≤ 64. A threads value of 0 means “use Rayon’s global thread pool size”.

Fields

tile_cols: u32

Number of tile columns (1–64).

tile_rows: u32

Number of tile rows (1–64).

threads: usize

Worker thread count (0 = auto).

Implementations

Source

impl TileConfig

pub fn new(tile_cols: u32, tile_rows: u32, threads: usize) -> CodecResult<Self>

Create a validated TileConfig.

Errors

Returns CodecError::InvalidParameter if:

  • tile_cols or tile_rows is 0 or greater than 64, or
  • the total tile count exceeds 4 096.
pub const fn tile_count(&self) -> u32

Total number of tiles.

pub fn thread_count(&self) -> usize

Effective thread count (resolves 0 to the rayon pool size).

pub fn auto(width: u32, height: u32, threads: usize) -> Self

Choose a reasonable tile layout for width × height and threads.

Selects the largest power-of-two tile counts that keep individual tile areas reasonable (≥ 64 × 64 pixels) while not exceeding the thread count.