TileCoord

Struct TileCoord 

pub struct TileCoord {
    pub col: u32,
    pub row: u32,
    pub x: u32,
    pub y: u32,
    pub width: u32,
    pub height: u32,
    pub index: u32,
}
Pixel coordinates and dimensions of a single tile within a frame.

Fields

col: u32

Tile column index (0-based).

row: u32

Tile row index (0-based).

x: u32

X offset in pixels.

y: u32

Y offset in pixels.

width: u32

Tile width in pixels.

height: u32

Tile height in pixels.

index: u32

Linear raster index (row * tile_cols + col).

Implementations

Source

impl TileCoord

pub const fn new( col: u32, row: u32, x: u32, y: u32, width: u32, height: u32, tile_cols: u32, ) -> Self

Create a new TileCoord.

pub const fn area(&self) -> u32

Tile area in pixels.

pub const fn is_left_edge(&self) -> bool

True if this tile is at the left frame boundary.

pub const fn is_top_edge(&self) -> bool

True if this tile is at the top frame boundary.