pub enum TileDependencyKind {
MotionVector,
LoopFilter,
EntropyContext,
}Expand description
The type of dependency one tile has on another.
Variants
MotionVector
Motion vector crosses into adjacent tile.
LoopFilter
In-loop filter requires border pixels from neighbour.
EntropyContext
Entropy context is shared with the tile to the left.