encode_tiles_wavefront

Function encode_tiles_wavefront 

pub fn encode_tiles_wavefront<F>(
    graph: &TileDependencyGraph,
    work_items: Vec<TileWorkItem>,
    encode_fn: F,
) -> Result<Vec<TileBuffer>, String>
Encodes tiles in dependency-aware waves using Rayon.

Tiles with satisfied dependencies are encoded in parallel waves. Returns encoded tile buffers in the order they were submitted.