TileRegion

Struct TileRegion 

pub struct TileRegion {
    pub col: u32,
    pub row: u32,
    pub x: u32,
    pub y: u32,
    pub width: u32,
    pub height: u32,
}
Pixel coordinates and dimensions of a single tile within a frame.

use oximedia_codec::tile_encoder::TileRegion;

let region = TileRegion::new(1, 0, 512, 0, 512, 288);
assert_eq!(region.area(), 512 * 288);
assert!(region.contains(600, 100));
assert!(!region.contains(200, 100)); // left of tile

Fields

col: u32

Tile column index (0-based).

row: u32

Tile row index (0-based).

x: u32

X pixel offset from the left of the frame.

y: u32

Y pixel offset from the top of the frame.

width: u32

Tile width in pixels.

height: u32

Tile height in pixels.

Implementations

Source

impl TileRegion

pub const fn new( col: u32, row: u32, x: u32, y: u32, width: u32, height: u32, ) -> Self

Create a new TileRegion.

pub const fn area(&self) -> u64

Area of this tile in pixels.

pub const fn contains(&self, px: u32, py: u32) -> bool

Returns true if the pixel (px, py) falls within this tile.

pub fn pixel_range_x(&self) -> Range<u32>

Pixel column range x..(x + width).

pub fn pixel_range_y(&self) -> Range<u32>

Pixel row range y..(y + height).