pub struct WebpAnimDecoder;Expand description
Decoder for animated WebP files.
Implementations
Sourceimpl WebpAnimDecoder
impl WebpAnimDecoder
Sourcepub fn decode(data: &[u8]) -> CodecResult<(Vec<WebpAnimFrame>, WebpAnimConfig)>
pub fn decode(data: &[u8]) -> CodecResult<(Vec<WebpAnimFrame>, WebpAnimConfig)>
Decode an animated WebP byte stream into frames and configuration.
Returns the decoded frames (with RGBA pixel data) and animation config.
Sourcepub fn frame_count(data: &[u8]) -> CodecResult<u32>
pub fn frame_count(data: &[u8]) -> CodecResult<u32>
Return the number of animation frames without fully decoding all pixel data.
Sourcepub fn is_webp_anim(data: &[u8]) -> bool
pub fn is_webp_anim(data: &[u8]) -> bool
Return true if the byte slice is a valid animated WebP (RIFF+WEBP with ANIM chunk).