BitstreamFilterError

Enum BitstreamFilterError 

pub enum BitstreamFilterError {
    BufferTooShort {
        needed: usize,
        available: usize,
    },
    InvalidLengthPrefix {
        offset: usize,
        claimed: usize,
        available: usize,
    },
    MalformedObuHeader {
        offset: usize,
    },
    MalformedSequenceHeader,
    EmptyPacket,
    UnknownNalType(u8),
    InvalidLengthPrefixSize(u8),
}
Errors that can occur during bitstream filtering operations.

Variants



BufferTooShort

Input buffer is too short for the requested operation.

Fields

needed: usize

Number of bytes needed.

available: usize

Number of bytes actually available.



InvalidLengthPrefix

A NAL unit length prefix encoded a size that exceeds available data.

Fields

offset: usize

Byte offset of the length prefix within the buffer.

claimed: usize

Number of bytes claimed by the prefix.

available: usize

Number of bytes actually remaining after the prefix.



MalformedObuHeader

An OBU header or extension byte was malformed.

Fields

offset: usize

Byte offset of the malformed header within the buffer.



MalformedSequenceHeader

The AV1 sequence header RBSP is malformed.



EmptyPacket

Attempted to convert an empty packet.



UnknownNalType(u8)

NAL unit type is not recognized for the requested operation.



InvalidLengthPrefixSize(u8)

Length prefix size is not 1, 2, or 4.