pub enum BitstreamFilterError {
BufferTooShort {
needed: usize,
available: usize,
},
InvalidLengthPrefix {
offset: usize,
claimed: usize,
available: usize,
},
MalformedObuHeader {
offset: usize,
},
MalformedSequenceHeader,
EmptyPacket,
UnknownNalType(u8),
InvalidLengthPrefixSize(u8),
}Expand description
Errors that can occur during bitstream filtering operations.
Variants
BufferTooShort
Input buffer is too short for the requested operation.
InvalidLengthPrefix
A NAL unit length prefix encoded a size that exceeds available data.
Fields
MalformedObuHeader
An OBU header or extension byte was malformed.
MalformedSequenceHeader
The AV1 sequence header RBSP is malformed.
EmptyPacket
Attempted to convert an empty packet.
UnknownNalType(u8)
NAL unit type is not recognized for the requested operation.
InvalidLengthPrefixSize(u8)
Length prefix size is not 1, 2, or 4.