pub struct LevelRange {
pub luma_min: u16,
pub luma_max: u16,
pub chroma_min: u16,
pub chroma_max: u16,
}Expand description
Level range for a given color range and bit depth.
Fields
luma_min: u16Minimum luma value.
luma_max: u16Maximum luma value.
chroma_min: u16Minimum chroma value.
chroma_max: u16Maximum chroma value.
Implementations
Sourceimpl LevelRange
impl LevelRange
Sourcepub fn new(range: ColorRange, depth: BitDepth) -> Self
pub fn new(range: ColorRange, depth: BitDepth) -> Self
Create a level range for the given color range and bit depth.
Sourcepub fn chroma_span(&self) -> u16
pub fn chroma_span(&self) -> u16
Chroma span (max - min).