pub struct SilkFrameHeader {
pub vad_flag: bool,
pub lbrr_flag: bool,
pub signal_type: u8,
pub quantization_offset: u8,
}Expand description
Parsed header fields from a SILK frame.
Fields
vad_flag: boolVoice activity detection flag.
lbrr_flag: boolLow Bitrate Redundancy (LBRR) payload present.
signal_type: u8Signal type: 0 = inactive, 1 = voiced, 2 = unvoiced.
quantization_offset: u8Quantization offset type (0 or 1).
Implementations
Sourceimpl SilkFrameHeader
impl SilkFrameHeader
Sourcepub fn parse(data: &[u8]) -> Result<Self, String>
pub fn parse(data: &[u8]) -> Result<Self, String>
Parses a SilkFrameHeader from the first byte(s) of a raw frame.
The SILK frame header is packed into the leading bits of the payload. This parser reads the minimum information needed to scaffold frame processing; full SILK decoding requires an entropy/range decoder.
Layout of byte 0:
Bit 7: VAD flag
Bit 6: LBRR flag
Bits 5-4: signal_type (0-2, values 0b11 treated as inactive)
Bit 3: quantization_offset
Bits 2-0: reserved / additional payload bitsTrait Implementations
Sourceimpl Clone for SilkFrameHeader
impl Clone for SilkFrameHeader
Sourcefn clone(&self) -> SilkFrameHeader
fn clone(&self) -> SilkFrameHeader
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SilkFrameHeader
impl Debug for SilkFrameHeader
Sourceimpl PartialEq for SilkFrameHeader
impl PartialEq for SilkFrameHeader
impl Eq for SilkFrameHeader
impl StructuralPartialEq for SilkFrameHeader