pub struct SliceHeader {
pub slice_type: SliceType,
pub frame_num: u16,
pub pic_parameter_set_id: u8,
pub field_pic_flag: bool,
pub bottom_field_flag: bool,
pub idr_pic_id: Option<u16>,
pub nal_ref_idc: u8,
}Expand description
Parsed fields from a slice header.
Fields
slice_type: SliceTypeSlice type.
frame_num: u16frame_num syntax element (wraps at MaxFrameNum).
pic_parameter_set_id: u8PPS id referenced by this slice.
field_pic_flag: boolfield_pic_flag: true when this slice belongs to a field (not a frame).
bottom_field_flag: boolbottom_field_flag: relevant only when field_pic_flag is true.
idr_pic_id: Option<u16>IDR picture id (only meaningful for IDR slices).
nal_ref_idc: u8nal_ref_idc from the enclosing NAL unit (0 = non-reference).
Implementations
Sourceimpl SliceHeader
impl SliceHeader
Sourcepub fn is_reference(&self) -> bool
pub fn is_reference(&self) -> bool
Returns true if this slice is a reference slice (nal_ref_idc > 0).
Sourcepub fn is_keyframe(&self) -> bool
pub fn is_keyframe(&self) -> bool
Returns true if this is a key-frame (IDR or I-slice that is reference).