pub struct TileCoord {
pub col: u32,
pub row: u32,
pub x: u32,
pub y: u32,
pub width: u32,
pub height: u32,
pub index: u32,
}Expand description
Pixel coordinates and dimensions of a single tile within a frame.
Fields
col: u32Tile column index (0-based).
row: u32Tile row index (0-based).
x: u32X offset in pixels.
y: u32Y offset in pixels.
width: u32Tile width in pixels.
height: u32Tile height in pixels.
index: u32Linear raster index (row * tile_cols + col).
Implementations
Sourceimpl TileCoord
impl TileCoord
Sourcepub const fn new(
col: u32,
row: u32,
x: u32,
y: u32,
width: u32,
height: u32,
tile_cols: u32,
) -> Self
pub const fn new( col: u32, row: u32, x: u32, y: u32, width: u32, height: u32, tile_cols: u32, ) -> Self
Create a new TileCoord.
Sourcepub const fn is_left_edge(&self) -> bool
pub const fn is_left_edge(&self) -> bool
True if this tile is at the left frame boundary.
Sourcepub const fn is_top_edge(&self) -> bool
pub const fn is_top_edge(&self) -> bool
True if this tile is at the top frame boundary.